@@ -1,29 +1,27 @@
 /*
- * Copyright (C) 2010 Volodymyr Tarasenko <tvntsr@yahoo.com>
- *               2010 Sergey Pavlov <sergey.pavlov@gmail.com>
- *               2010 PortaOne Inc.
+ * Copyright (C) 2010-2013 Volodymyr Tarasenko <tvntsr@yahoo.com>
+ *              2010      Sergey Pavlov <sergey.pavlov@gmail.com>
+ *              2010      PortaOne Inc.
  * Copyright (C) Tildeslash Ltd. All rights reserved.
  *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 3.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
  *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
  *
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.
- */
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
+ */ 
 
 #include "Config.h"
 
@@ -63,7 +61,8 @@ const struct Pop_T oraclepops = {
         OraclePreparedStatement_setDouble,
         OraclePreparedStatement_setBlob,
         OraclePreparedStatement_execute,
-        OraclePreparedStatement_executeQuery
+        OraclePreparedStatement_executeQuery,
+        OraclePreparedStatement_rowsChanged
 };
 typedef struct param_t {
         union {
@@ -86,6 +85,7 @@ struct T {
         OCISvcCtx* svc;
         param_t    params;
         sword      lastError;
+        ub4        rowsChanged;
 };
 
 #define TEST_INDEX \
@@ -115,6 +115,7 @@ T OraclePreparedStatement_new(OCIStmt *stmt, OCIEnv *env, OCIError *err, OCISvcC
         P->svc  = svc;
         P->maxRows = max_row;
         P->lastError = OCI_SUCCESS;
+        P->rowsChanged = 0;
         /* paramCount */
         P->lastError = OCIAttrGet(P->stmt, OCI_HTYPE_STMT, &P->paramCount, NULL, OCI_ATTR_BIND_COUNT, P->err);
         if (P->lastError != OCI_SUCCESS && P->lastError != OCI_SUCCESS_WITH_INFO)
@@ -195,14 +196,19 @@ void OraclePreparedStatement_setBlob(T P, int parameterIndex, const void *x, int
 
 void OraclePreparedStatement_execute(T P) {
         assert(P);
+        P->rowsChanged = 0;
         P->lastError = OCIStmtExecute(P->svc, P->stmt, P->err, 1, 0, NULL, NULL, OCI_DEFAULT);
         if (P->lastError != OCI_SUCCESS && P->lastError != OCI_SUCCESS_WITH_INFO)
                 THROW(SQLException, "%s", OraclePreparedStatement_getLastError(P->lastError, P->err));
+        P->lastError = OCIAttrGet( P->stmt, OCI_HTYPE_STMT, &P->rowsChanged, 0, OCI_ATTR_ROW_COUNT, P->err);
+        if (P->lastError != OCI_SUCCESS && P->lastError != OCI_SUCCESS_WITH_INFO)
+                THROW(SQLException, "%s", OraclePreparedStatement_getLastError(P->lastError, P->err));
 }
 
 
 ResultSet_T OraclePreparedStatement_executeQuery(T P) {
         assert(P);
+        P->rowsChanged = 0;
         P->lastError = OCIStmtExecute(P->svc, P->stmt, P->err, 0, 0, NULL, NULL, OCI_DEFAULT);
         if (P->lastError == OCI_SUCCESS || P->lastError == OCI_SUCCESS_WITH_INFO)
                 return ResultSet_new(OracleResultSet_new(P->stmt, P->env, P->err, P->svc, false, P->maxRows), (Rop_T)&oraclerops);
@@ -210,6 +216,13 @@ ResultSet_T OraclePreparedStatement_executeQuery(T P) {
         return NULL;
 }
 
+
+long long int OraclePreparedStatement_rowsChanged(T P) {
+        assert(P);
+        return P->rowsChanged;
+}
+
+
 /* Error handling: Oracle requires a buffer to store
    error message, to keep error handling thread safe
    TSD is used
